==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapPolicyEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapPolicyEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapPolicyEntity.AbstractMapPolicyEntity implements org.keycloak.models.map.authorization.entity.MapPolicyEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> entityFieldDelegate;
    public MapPolicyEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return (org.keycloak.representations.idm.authorization.DecisionStrategy) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY);
    }
    @SuppressWarnings("unchecked") @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.Logic getLogic() {
        return (org.keycloak.representations.idm.authorization.Logic) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC);
    }
    @SuppressWarnings("unchecked") @Override public void setLogic(org.keycloak.representations.idm.authorization.Logic p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfigs() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS);
    }
    @SuppressWarnings("unchecked") @Override public void setConfigs(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getConfig(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeConfig(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getAssociatedPolicyIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addAssociatedPolicyId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeAssociatedPolicyId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getResourceIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addResourceId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeResourceId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getScopeIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addScopeId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeScopeId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOwner() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER);
    }
    @SuppressWarnings("unchecked") @Override public void setOwner(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapPolicyEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapPolicyEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapPolicyEntity.AbstractMapPolicyEntity implements org.keycloak.models.map.authorization.entity.MapPolicyEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> entityFieldDelegate;
    public MapPolicyEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPolicyEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return (org.keycloak.representations.idm.authorization.DecisionStrategy) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY);
    }
    @SuppressWarnings("unchecked") @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.Logic getLogic() {
        return (org.keycloak.representations.idm.authorization.Logic) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC);
    }
    @SuppressWarnings("unchecked") @Override public void setLogic(org.keycloak.representations.idm.authorization.Logic p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfigs() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS);
    }
    @SuppressWarnings("unchecked") @Override public void setConfigs(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getConfig(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeConfig(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getAssociatedPolicyIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addAssociatedPolicyId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeAssociatedPolicyId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getResourceIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addResourceId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeResourceId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getScopeIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addScopeId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeScopeId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOwner() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER);
    }
    @SuppressWarnings("unchecked") @Override public void setOwner(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER, p0);
    }
}
